#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# Copyright (C) 2022, Jan-Philipp Litza (PLUTEX) <jpl@plutex.de>.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

# modifications by thl-cmk[at]outlook[dot]com
# 2024-04-21: fixed missing FixedValue in import
#             changed Alternative titles to "Upper levels in qps"/"Upper levels in %" to better differentiate between them
#             added explicit unit "%2
#             added ruleset for bakery
#             renamed to unbound.py (from unbound_parameters.py)
#             moved to ~/local/lib/check_mk/gui/plugins/wato/check_parameters (from local/share/check_mk/web/plugins/wato)
# 2024-05-14: separated WATO for bakery and check in two files
# 2024-05-22: added ruleset for unwanted replies

from cmk.gui.i18n import _
from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithoutItem,
    RulespecGroupCheckParametersApplications,
    rulespec_registry,
)

from cmk.gui.valuespec import (
    Alternative,
    Dictionary,
    FixedValue,
    Float,
    Percentage,
    Tuple,
)


def _parameter_valuespec_unbound_answers():
    return Dictionary(
        title=_('Unbound answers'),
        elements=[
            (f'levels_upper_{answer}',
             Alternative(
                 title=f'Upper levels for {answer} answers',
                 show_alternative_title=True,
                 elements=[
                     Tuple(
                         elements=[
                             Float(title=_('Warning at'), unit=_('qps')),
                             Float(title=_('Critical at'), unit=_('qps')),
                         ],
                         title=_('Upper levels in qps'),
                         orientation='horizontal',
                     ),
                     Tuple(
                         elements=[
                             Percentage(title=_('Warning at'), unit=_('%')),
                             Percentage(title=_('Critical at'), unit=_('%')),
                             FixedValue(value='%', totext=''),  # needed to decide between both variants
                         ],
                         title=_('Upper levels in %'),
                         orientation='horizontal',
                     ),
                 ]))
            for answer in (
                'FORMERR',
                'NOERROR',
                'NOTIMPL',
                'NXDOMAIN',
                'REFUSED',
                'SERVFAIL',
                'nodata',
            )
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name='unbound_answers',
        group=RulespecGroupCheckParametersApplications,
        match_type='dict',
        parameter_valuespec=_parameter_valuespec_unbound_answers,
        title=lambda: _('Unbound Answers'),
    )
)
